[SCM] ktp-accounts-kcm packaging branch, master, updated. debian/15.12.1-1-1157-gc4589c5

Maximiliano Curia maxy at moszumanska.debian.org
Fri May 27 23:57:18 UTC 2016


Gitweb-URL: http://git.debian.org/?p=pkg-kde/applications/ktp-accounts-kcm.git;a=commitdiff;h=c8e6d53

The following commit has been merged in the master branch:
commit c8e6d533b8aebe4658903ff2f3d1a2f6b52f7e57
Author: George Goldberg <grundleborg at googlemail.com>
Date:   Wed Jul 22 18:12:57 2009 +0000

    Set up the model and add the connection managers when they become ready.
    
    svn path=/trunk/playground/network/telepathy-accounts-kcm/; revision=1001233
---
 src/protocol-select-widget.cpp | 12 ++++++++++--
 src/protocol-select-widget.ui  |  2 +-
 2 files changed, 11 insertions(+), 3 deletions(-)

diff --git a/src/protocol-select-widget.ui b/src/protocol-select-widget.ui
index e4b16ea..2b02c1e 100644
--- a/src/protocol-select-widget.ui
+++ b/src/protocol-select-widget.ui
@@ -15,7 +15,7 @@
   </property>
   <layout class="QVBoxLayout" name="verticalLayout_2">
    <item>
-    <widget class="QListView" name="m_protocolListView"/>
+    <widget class="QListView" name="protocolListView"/>
    </item>
   </layout>
  </widget>

diff --git a/src/protocol-select-widget.cpp b/src/protocol-select-widget.cpp
index 553dd24..97874e8 100644
--- a/src/protocol-select-widget.cpp
+++ b/src/protocol-select-widget.cpp
@@ -20,6 +20,8 @@
 
 #include "protocol-select-widget.h"
 
+#include "protocol-list-model.h"
+
 #include "ui_protocol-select-widget.h"
 
 #include <KDebug>
@@ -32,12 +34,14 @@ class ProtocolSelectWidget::Private
 {
 public:
     Private()
-     : ui(0)
+     : ui(0),
+       model(0)
     {
         kDebug();
     }
 
     Ui::ProtocolSelectWidget *ui;
+    ProtocolListModel *model;
 };
 
 ProtocolSelectWidget::ProtocolSelectWidget(QWidget *parent)
@@ -47,8 +51,11 @@ ProtocolSelectWidget::ProtocolSelectWidget(QWidget *parent)
     kDebug();
 
     // Set up the widget
+    d->model = new ProtocolListModel(this);
+
     d->ui = new Ui::ProtocolSelectWidget;
     d->ui->setupUi(this);
+    d->ui->protocolListView->setModel(d->model);
 
     // Load the list of all installed Telepathy Connection Managers Asynchronously
     QTimer::singleShot(0, this, SLOT(getConnectionManagerList()));
@@ -91,7 +98,8 @@ void ProtocolSelectWidget::onConnectionManagerListGot(Tp::PendingOperation *op)
     }
 
     foreach (QString cmName, psl->result()) {
-        // TODO: Add that CM to the protocol-list-model
+        // Add the CM to the ProtocolListModel
+        d->model->addConnectionManager(Tp::ConnectionManager::create(cmName));
     }
 }
 
-- 
ktp-accounts-kcm packaging



More information about the pkg-kde-commits mailing list